pub async fn generate_mass_status<C: ExecutionClient + ?Sized>(
client: &C,
lookback_mins: Option<u64>,
ts_init: UnixNanos,
) -> Result<Option<ExecutionMassStatus>>Expand description
Composes an execution mass status using the supplied client clock timestamp.
Errors
Returns an error if the lookback cannot be represented or a report source fails.